
import os
import time

import wx 
import wx.html2
import threading
import tornado.ioloop
import tornado.web

class MainHandler(tornado.web.RequestHandler):
    
    def get(self):
        self.render("main.html")

class TreeHandler(tornado.web.RequestHandler):

    def get(self):
        self.render("tree.html")

def make_app():
    settings = {
        "template_path": "html",
        "xsrf_cookies": False,
    }
    return tornado.web.Application([
        (r"/", MainHandler),
        (r"/tree", TreeHandler),
        (r"/static/(.*)", tornado.web.StaticFileHandler, {"path":"html/static"}),
    ], **settings)

def start_tornado():
    app = make_app()
    app.listen(8888)
    tornado.ioloop.IOLoop.current().start()

def stop_tornado():
    ioloop = tornado.ioloop.IOLoop.instance()
    ioloop.add_callback(lambda x: x.stop(), ioloop)
    print "Asked Tornado to exit"

    
class MyHtmlFrame(wx.Frame): 
   
    def __init__(self, parent, title):
        wx.Frame.__init__(self, parent, -1, title, size = (800,600))
        self.create_menu()
        self.Bind(wx.EVT_CLOSE, self.OnClose)

        self.statusbar = self.CreateStatusBar(2)
        self.statusbar.SetStatusText(u"status", 0)
        self.statusbar.SetStatusText(u"hello", 1)

        self.splitter = wx.SplitterWindow(self, style=wx.SP_LIVE_UPDATE)
        self.tree = wx.html2.WebView.New(self.splitter)
        #self.tree.EnableContextMenu(False)

        self.html = wx.html2.WebView.New(self.splitter)
        self.html.EnableContextMenu(False)

        self.splitter.SetMinimumPaneSize(200)
        self.splitter.SplitVertically(self.tree, self.html, 300)

        self.tree.LoadURL('http://localhost:8888/tree?v=%d'%time.time())
        self.html.LoadURL('http://localhost:8888?v=%d'%time.time())
    
    def create_menu(self):
        filemenu = wx.Menu()
        filemenu.Append(1, "Some option")
        filemenu.Append(2, "Another option")

        mi = wx.MenuItem(filemenu, 3, "&Quit\tCtrl+Q")
        mi.SetBitmap(wx.Bitmap("images/exit.png"))
        filemenu.Append(mi)

        self.Bind(wx.EVT_MENU, self.OnQuit, id=3)

        menubar = wx.MenuBar()
        menubar.Append(filemenu, "&File")
        self.SetMenuBar(menubar)
        
        toolbar = wx.ToolBar(self)
        toolbar.SetToolBitmapSize((16, 16))
        toolbar.AddTool( 101, "Settings", wx.Bitmap("images/settings.png") )
        tb = toolbar.AddTool( 109, "Quit", wx.Bitmap("images/exit.png") )
        toolbar.Realize()
        self.SetToolBar(toolbar)

        self.Bind(wx.EVT_TOOL, self.OnQuit, tb)

    def OnClose(self, event):
        self.Destroy()

    def OnQuit(self, event):
        self.Close()

if __name__ == "__main__":
    p = threading.Thread(target = start_tornado)
    p.start()
    
    app = wx.App()  
    frm = MyHtmlFrame(None, "HTML Browser")  
    frm.Show()  
    app.MainLoop()
    
    stop_tornado()
    p.join()

    